IntRange class

A range of integers.

Constructors

IntRange(int from, int length)
const

Properties

from → int
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → int
no setter

Methods

isIn(int index) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited